@@ -42,7 +42,8 @@ class Page:
 
         :param page_number: The number of the page (1-based index)
         :param document_id: The unique id of the document
-        :param path:
+        :param path: Local or remote path to the document folder,
+            which includes the image and ocr files
         :param image_width: Page image width
         :param image_height: Page image height
         """
