@@ -378,22 +378,31 @@ class Model(metaclass=abc.ABCMeta):
             otherwise detects if there is a match between two extraction tags
             having the same page number. Returns true if
         intersection is greater than the threshold"""
+        is_match = False
         if isinstance(act_tag, TDTag) and isinstance(pred_tag, TDTag):
-            return act_tag.html_id == pred_tag.html_id
+            cell_xpath = max(act_tag.xpath, pred_tag.xpath, key=len)
+            field_xpath = min(act_tag.xpath, pred_tag.xpath, key=len)
+            is_match = field_xpath in cell_xpath \
+                and act_tag.col_index == pred_tag.col_index\
+                and act_tag.row_index == pred_tag.row_index
         elif ((isinstance(act_tag, TDTag)
               and isinstance(pred_tag, HTMLTableTag)) or
               (isinstance(act_tag, HTMLTableTag)
                and isinstance(pred_tag, TDTag))):
-            return act_tag.tag_id == pred_tag.tag_id
+            is_match = act_tag.tag_id == pred_tag.tag_id
         else:
-            return act_tag.page.page_number == pred_tag.page.page_number and (
-                    act_tag & pred_tag) / min(
-                act_tag, pred_tag, key=lambda x: x.area).area >= threshold
+            is_match = (
+                    act_tag.page.page_number == pred_tag.page.page_number
+                    and ((act_tag & pred_tag) / min(act_tag, pred_tag,
+                         key=lambda x: x.area).area >= threshold)
+            )
+        return is_match
 
     def execute_eval(self,
                      token: str,
                      url: str,
-                     model_version: str
+                     model_version: str,
+                     ground_truth_id: str = None,
                      ) -> List[requests.Response]:
         """ Execute evaluation for a given model_version """
         session = requests.Session()
@@ -401,11 +410,14 @@ class Model(metaclass=abc.ABCMeta):
         session.mount('https://', HTTPAdapter(max_retries=self.RETRIES))
         session.headers = {'x-auth': token}
 
-        ground_truth_ids = session.get(
-            url=f'{url}/groundtruths/{model_version}',
-            verify=False,
-            timeout=self.DEFAULT_TIMEOUT
-        ).json()
+        if ground_truth_id is None:
+            ground_truth_ids = session.get(
+                url=f'{url}/groundtruths/{model_version}',
+                verify=False,
+                timeout=self.DEFAULT_TIMEOUT
+            ).json()
+        else:
+            ground_truth_ids = [ground_truth_id]
 
         post_responses = []
         for gt_id in ground_truth_ids:
